@@ -17,19 +17,18 @@ INSERT INTO dem.message_inbox (
 ) VALUES (
 	(select pk from dem.staff where db_user = 'any-doc'),
 	(select pk_type from dem.v_inbox_item_type where type = 'memo' and category = 'administrative'),
-	'Release Notes for GNUmed 1.5.6 (database v20.6)',
-	'GNUmed 1.5.6 Release Notes:
+	'Release Notes for GNUmed 1.5.8 (database v20.8)',
+	'GNUmed 1.5.8 Release Notes:
 
-	1.5.6
+	1.5.8
 
-FIX: exception on removing temporary config file [thanks Vaibhav]
-FIX: exception on importing duplicate file into export area
-FIX: exception on merging patients under wxPython 3 [thanks max]
+FIX: SQL formatting when retrieving clinical narrative [thanks Marc]
+FIX: strange case of "curr_pat is None" in top panel [thanks Marc]
 
-	20.6
+	20.8
 
 no changes
 ');
 
 -- --------------------------------------------------------------
-select gm.log_script_insertion('v20-release_notes-dynamic.sql', '20.6');
+select gm.log_script_insertion('v20-release_notes-dynamic.sql', '20.8');
